#[non_exhaustive]pub struct StartSessionInputBuilder { /* private fields */ }Expand description
A builder for StartSessionInput.
Implementations
Sourceimpl StartSessionInputBuilder
impl StartSessionInputBuilder
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The session description.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The session description.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The session description.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The workgroup to which the session belongs.
This field is required.Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The workgroup to which the session belongs.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The workgroup to which the session belongs.
Sourcepub fn engine_configuration(self, input: EngineConfiguration) -> Self
pub fn engine_configuration(self, input: EngineConfiguration) -> Self
Contains engine data processing unit (DPU) configuration settings and parameter mappings.
This field is required.Sourcepub fn set_engine_configuration(
self,
input: Option<EngineConfiguration>,
) -> Self
pub fn set_engine_configuration( self, input: Option<EngineConfiguration>, ) -> Self
Contains engine data processing unit (DPU) configuration settings and parameter mappings.
Sourcepub fn get_engine_configuration(&self) -> &Option<EngineConfiguration>
pub fn get_engine_configuration(&self) -> &Option<EngineConfiguration>
Contains engine data processing unit (DPU) configuration settings and parameter mappings.
Sourcepub fn execution_role(self, input: impl Into<String>) -> Self
pub fn execution_role(self, input: impl Into<String>) -> Self
The ARN of the execution role used to access user resources for Spark sessions and Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and Identity Center enabled workgroups.
Sourcepub fn set_execution_role(self, input: Option<String>) -> Self
pub fn set_execution_role(self, input: Option<String>) -> Self
The ARN of the execution role used to access user resources for Spark sessions and Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and Identity Center enabled workgroups.
Sourcepub fn get_execution_role(&self) -> &Option<String>
pub fn get_execution_role(&self) -> &Option<String>
The ARN of the execution role used to access user resources for Spark sessions and Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and Identity Center enabled workgroups.
Sourcepub fn monitoring_configuration(self, input: MonitoringConfiguration) -> Self
pub fn monitoring_configuration(self, input: MonitoringConfiguration) -> Self
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn set_monitoring_configuration(
self,
input: Option<MonitoringConfiguration>,
) -> Self
pub fn set_monitoring_configuration( self, input: Option<MonitoringConfiguration>, ) -> Self
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn get_monitoring_configuration(&self) -> &Option<MonitoringConfiguration>
pub fn get_monitoring_configuration(&self) -> &Option<MonitoringConfiguration>
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn notebook_version(self, input: impl Into<String>) -> Self
pub fn notebook_version(self, input: impl Into<String>) -> Self
The notebook version. This value is supplied automatically for notebook sessions in the Athena console and is not required for programmatic session access. The only valid notebook version is Athena notebook version 1. If you specify a value for NotebookVersion, you must also specify a value for NotebookId. See EngineConfiguration$AdditionalConfigs.
Sourcepub fn set_notebook_version(self, input: Option<String>) -> Self
pub fn set_notebook_version(self, input: Option<String>) -> Self
The notebook version. This value is supplied automatically for notebook sessions in the Athena console and is not required for programmatic session access. The only valid notebook version is Athena notebook version 1. If you specify a value for NotebookVersion, you must also specify a value for NotebookId. See EngineConfiguration$AdditionalConfigs.
Sourcepub fn get_notebook_version(&self) -> &Option<String>
pub fn get_notebook_version(&self) -> &Option<String>
The notebook version. This value is supplied automatically for notebook sessions in the Athena console and is not required for programmatic session access. The only valid notebook version is Athena notebook version 1. If you specify a value for NotebookVersion, you must also specify a value for NotebookId. See EngineConfiguration$AdditionalConfigs.
Sourcepub fn session_idle_timeout_in_minutes(self, input: i32) -> Self
pub fn session_idle_timeout_in_minutes(self, input: i32) -> Self
The idle timeout in minutes for the session.
Sourcepub fn set_session_idle_timeout_in_minutes(self, input: Option<i32>) -> Self
pub fn set_session_idle_timeout_in_minutes(self, input: Option<i32>) -> Self
The idle timeout in minutes for the session.
Sourcepub fn get_session_idle_timeout_in_minutes(&self) -> &Option<i32>
pub fn get_session_idle_timeout_in_minutes(&self) -> &Option<i32>
The idle timeout in minutes for the session.
Sourcepub fn client_request_token(self, input: impl Into<String>) -> Self
pub fn client_request_token(self, input: impl Into<String>) -> Self
A unique case-sensitive string used to ensure the request to create the session is idempotent (executes only once). If another StartSessionRequest is received, the same response is returned and another session is not created. If a parameter has changed, an error is returned.
This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.
Sourcepub fn set_client_request_token(self, input: Option<String>) -> Self
pub fn set_client_request_token(self, input: Option<String>) -> Self
A unique case-sensitive string used to ensure the request to create the session is idempotent (executes only once). If another StartSessionRequest is received, the same response is returned and another session is not created. If a parameter has changed, an error is returned.
This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.
Sourcepub fn get_client_request_token(&self) -> &Option<String>
pub fn get_client_request_token(&self) -> &Option<String>
A unique case-sensitive string used to ensure the request to create the session is idempotent (executes only once). If another StartSessionRequest is received, the same response is returned and another session is not created. If a parameter has changed, an error is returned.
This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.
Appends an item to tags.
To override the contents of this collection use set_tags.
A list of comma separated tags to add to the session that is created.
A list of comma separated tags to add to the session that is created.
A list of comma separated tags to add to the session that is created.
Copies the tags from the Workgroup to the Session when.
Copies the tags from the Workgroup to the Session when.
Copies the tags from the Workgroup to the Session when.
Sourcepub fn build(self) -> Result<StartSessionInput, BuildError>
pub fn build(self) -> Result<StartSessionInput, BuildError>
Consumes the builder and constructs a StartSessionInput.
Sourceimpl StartSessionInputBuilder
impl StartSessionInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StartSessionOutput, SdkError<StartSessionError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StartSessionOutput, SdkError<StartSessionError, HttpResponse>>
Sends a request with this input using the given client.