#[non_exhaustive]pub struct StartSessionOutputBuilder { /* private fields */ }Expand description
A builder for StartSessionOutput.
Implementations
Sourceimpl StartSessionOutputBuilder
impl StartSessionOutputBuilder
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The session ID.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The session ID.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The session ID.
Sourcepub fn state(self, input: SessionState) -> Self
pub fn state(self, input: SessionState) -> Self
The state of the session. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn set_state(self, input: Option<SessionState>) -> Self
pub fn set_state(self, input: Option<SessionState>) -> Self
The state of the session. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn get_state(&self) -> &Option<SessionState>
pub fn get_state(&self) -> &Option<SessionState>
The state of the session. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn build(self) -> StartSessionOutput
pub fn build(self) -> StartSessionOutput
Consumes the builder and constructs a StartSessionOutput.